#!/bin/bash
#
# cluster.sh - clusters input CSV using ELKI and plots the result to PDF
#            - tested with ELKI 0.5.5, executable JAR is available at
#              http://elki.dbs.ifi.lmu.de/wiki/Releases
# 
# Copyright (C) 2012-2013, Masaryk University
# Author: Jan VYKOPAL <vykopal@ics.muni.cz>
#         
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of Masaryk University nor the names of its
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall Masaryk University or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.
#
# Version: 0.1
#
# $Id: cluster.sh 1190 2013-04-18 15:43:06Z 98724 $

if [ $# -ne 9 ];then
        echo "usage: ./cluster.sh <path_to_ELKI> <path_to_plotCluster> <path_to_clusterDetails> <input_file.csv> <epsilon> <minPts> <output_dir> <plot_file.pdf> <details-input_file.csv>"
        exit -1;
fi

ELKI=$1 
PLOT=$2 
CLUSTER_DETAILS=$3

IN=$4
EPS=$5
PTS=$6
OUTDIR=$7
PDF=$8
DETAILS_IN=$9

echo -n "Deleting previous results in '$OUTDIR'..."
rm -f $OUTDIR/cluster* $OUTDIR/main.txt $OUTDIR/noise.txt
echo 'OK'
echo
echo "Clustering '$IN' (DBSCAN, epsilon = $EPS, minPts = $PTS) to '$OUTDIR'..."
java -cp $ELKI de.lmu.ifi.dbs.elki.application.KDDCLIApplication -algorithm clustering.DBSCAN -dbc.in $IN -dbscan.epsilon $EPS -dbscan.minpts $PTS -time -evaluator NoAutomaticEvaluation -resulthandler ResultWriter -out $OUTDIR -out.silentoverwrite true -parser.vector-type IntegerVector
echo -n `ls $OUTDIR/cluster* | wc -l`
echo ' clusters found'
echo
echo "Plotting clusters to '$PDF'..." # without noise
$PLOT $OUTDIR/ $PDF FALSE
echo
echo "Reading biflow details from '$DETAILS_IN'..."
# head $DETAILS_IN
$CLUSTER_DETAILS $OUTDIR $DETAILS_IN
