#!/usr/bin/perl
#
# clusterDetails.pl - maps results from ELKI to details of biflows in 
#                     CSV, outputs to the stdout
# 
# Copyright (C) 2012-2013, Masaryk University
# Author: Jan VYKOPAL <vykopal@ics.muni.cz>
#         
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of Masaryk University nor the names of its
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall Masaryk University or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.
#
# Version: 0.1
#
# $Id: clusterDetails.pl 1192 2013-04-18 20:36:50Z 98724 $

use strict;

my $ARGC = @ARGV;

if ($ARGC != 2) {
    die "usage: ./clusterDetails.pl <output_dir> <input_file_details>\n";
}

my $output_dir = $ARGV[0];
my $input_file_details = $ARGV[1];

my @files = `ls $output_dir/cluster* $output_dir/noise.txt`;

open DETAILS, "<$input_file_details" or die $!;
my @details = <DETAILS>;

foreach (@files) {
  open FILE, "<$_" or die $!;
  print "$_\n";
  my @clusters = <FILE>;

  my @sips;
  my @dips;

  my %sip_count = ();
  my %dip_count = ();

  foreach (@clusters) {
    # print $_;
    if ($_ =~ m/ID=([0-9]+).*/) {
      print $details[$1];
      my @biflow = split(/,/,$details[$1]);
      push (@sips, $biflow[4]);
      push (@dips, $biflow[6]);
      ++$sip_count{$biflow[4]};
      ++$dip_count{$biflow[6]};
    }
  }
  print "\n";
  my $cluster_size = scalar (@sips);
  @sips = uniq(@sips);
  @dips = uniq(@dips);
  print "Cluster size: $cluster_size\n";
  print scalar (@sips), " source IPs: @sips\n\n";
  for (sort keys %sip_count) { print "$_\t$sip_count{$_}\n" };
  print "\n";
  print scalar (@dips), " destination IPs: @dips\n\n";
  for (sort keys %dip_count) { print "$_\t$dip_count{$_}\n" };
  close FILE;
}

close DETAILS;

sub uniq {
  my %seen;
  return grep { !$seen{$_}++ } @_;
}
