#!/usr/bin/Rscript
#
# plotClusters.R - plots clusters produced by ELKI using R parallel 
#                  coordinate plot library, outputs a PDF file
# 
# Copyright (C) 2012-2013, Masaryk University
# Author: Jan VYKOPAL <vykopal@ics.muni.cz>
#         
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of Masaryk University nor the names of its
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall Masaryk University or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.
#
# Version: 0.1
#
# $Id: plotClusters.R 1190 2013-04-18 15:43:06Z 98724 $

library(lattice)

args=commandArgs(trailingOnly = TRUE);

if (length(args) != 3) {
	stop("usage: ./plotClusters.R <ELKI_output_dir_with_the_trailing/> <PDF_output_file> <with/without_noise (TRUE/FALSE)>")
} 

dir=args[1]; # dir with output from Elki
plot_pdf=args[2]; # name of the result file
noise=args[3]; # with or without noise? TRUE or FALSE

files=list.files(dir, pattern=ifelse(noise == TRUE, 'cluster*|noise.txt','cluster*'));

result='/tmp/clusters-labeled.csv'

# read clusters in separate files produced by ELKI and append them to 
# the one CSV file with an appropriate label
for (i in 1:length(files)) {
    name=files[i]
    filename=paste(dir, name, collapse='', sep='')
    cat(name,"\n")
    data=read.table(filename, col.names=c('id', 'pkt_fwd','pkt_rvs','byt_fwd','byt_rvs'));
    data[1]=NULL
    data[5]=i
    write.table(data, file=result, append=ifelse(i == 1, FALSE, TRUE), col.names=FALSE, row.names=FALSE)
    print(head(data))
}

all_data=read.table(result, col.names=c('pkt_fwd','pkt_rvs','byt_fwd','byt_rvs','label'))

# set y-axis values
# yrange=1:100;
yrange=all_data;

# create parallel coordinates
p = parallelplot(all_data[,1:4], groups=all_data[,5], horizon=FALSE, ylim = extendrange(range(yrange)), 
scales = list(y = list(at = NULL, labels = NULL),x=list()), lower = 0, upper = 1, 
panel=function(x,y,z,...){panel.abline(v=1:ncol(all_data),col="gray90"); panel.parallel(x,y,z,...)}, 
main = 'Clustered traffic (scaled)', xlab = '', ylab = '', auto.key=TRUE)

# plot to PDF file
# pdf(file=plot_pdf);
pdf(file=plot_pdf, width=9);
print(p)
dev.off();
