#!/usr/bin/Rscript
#
# scale.R - scales 3rd and 4th column of input CSV by a user defined 
#           factor and saves to a new file
# 
# Copyright (C) 2012-2013, Masaryk University
# Author: Jan VYKOPAL <vykopal@ics.muni.cz>
#         
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of Masaryk University nor the names of its
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall Masaryk University or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.
#
# Version: 0.1
#
# $Id: scale.R 1179 2013-04-17 12:12:34Z 98724 $

args=commandArgs(trailingOnly = TRUE);

if (length(args) != 3) {
	stop("usage: ./scale.R <input_file.csv> <factor> <output_file>")
} 

file=args[1];
factor=as.numeric(args[2]);
output=args[3];

cat("Scaling byt_fwd and byt_rvs in", file, "by", factor, "to", output, "...")

data=read.csv(file, row.names=NULL);

xn=cbind(pkt_fwd=data[,1], pkt_rvs=data[,2], byt_fwd=floor(data[,3]/factor), byt_rvs=floor(data[,4]/factor))

write.table(xn, file = output, row.names=FALSE);

cat(" OK\n")
