#!/bin/bash
#
# simFlow.sh - reads unidirectional flow from nfcapd files,
#            - extracts volume characteristics,
#            - scales the numbers of transferred bytes by a user defined
#              factor,
#            - clusters input CSV using ELKI, 
#            - plots the result to PDF and
#            - inspects clusters for attack classes
# 
# Copyright (C) 2012-2013, Masaryk University
# Author: Jan VYKOPAL <vykopal@ics.muni.cz>
#         
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of Masaryk University nor the names of its
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
#
# This software is provided ``as is'', and any express or implied
# warranties, including, but not limited to, the implied warranties of
# merchantability and fitness for a particular purpose are disclaimed.
# In no event shall Masaryk University or contributors be liable for
# any direct, indirect, incidental, special, exemplary, or consequential
# damages (including, but not limited to, procurement of substitute
# goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether
# in contract, strict liability, or tort (including negligence or
# otherwise) arising in any way out of the use of this software, even
# if advised of the possibility of such damage.
#
# Version: 0.1
#
# $Id: simFlow.sh 1192 2013-04-18 20:36:50Z 98724 $

if [ $# -ne 10 ];then
        echo "usage: ./simFlow.sh <path_to_scripts> <path_to_ELKI> <input_nfcapd_file> <filter> <time_window> <scale_factor> <epsilon> <minPts> <plot_file.pdf> <ratio>"
        exit -1;
fi

SCRIPTS=$1
ELKI=$2
NFCAPD=$3
FILTER=$4
TIME=$5
FACTOR=$6
EPS=$7
PTS=$8
PLOTFILE=$9
RATIO=$10

echo "=== 1. EXTRACT VOLUME CHARACTERISTICS OF BIFLOWS ==="
echo "Read data from a nfcapd file and pair unidirectional flows to biflows, extract volume characteristics"
# use PID of this script as the name for the output file
$SCRIPTS/nfcapd2biflowcsv.pl $NFCAPD "$FILTER" $TIME $$.csv
head $$.csv details-$$.csv

echo
echo "=== 2. SCALE BYTES ==="
echo "Scale bytes in biflows"
$SCRIPTS/scale.R $$.csv $FACTOR $$-scaled.csv
head $$-scaled.csv

echo
echo "=== 3. CLUSTER ==="
echo "Cluster extracted data by DBSCAN and plot the results (without noise)"
$SCRIPTS/cluster.sh $ELKI $SCRIPTS/plotClusters.R $SCRIPTS/clusterDetails.pl $$-scaled.csv $EPS $PTS output-$$ $PLOTFILE details-$$.csv

echo
echo "=== 4. INSPECT ==="
echo "Inspect clusters for three classes of brute force attacks: simple (SBA), multiple (MBA) and distributed (DBA)"
echo "Ratio for MBAs and DBAs is set to $RATIO"
$SCRIPTS/clusterDetails-inspect.pl output-$$ details-$$.csv $RATIO | tee $$-inspect.txt

echo
echo "=== FOUND ATTACKS ==="
grep SBA $$-inspect.txt
grep MBA $$-inspect.txt
grep DBA $$-inspect.txt
rm -f $$-inspect.txt
